==> jboss-metadata-common-7.0.8.Final-sources.jar: org/jboss/metadata/property/PropertiesPropertyResolver.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.metadata.property;

import java.util.Properties;

/**
 * Resolves properties using a {@code Properties} object.
 *
 * @author John Bailey
 */
public class PropertiesPropertyResolver implements PropertyResolver {
    private final Properties deploymentProperties;

    public PropertiesPropertyResolver(final Properties deploymentProperties) {
        this.deploymentProperties = deploymentProperties;
    }

    public String resolve(final String propertyName) {
        return deploymentProperties.getProperty(propertyName);
    }
}

==> jboss-metadata-common-9.0.0.Final-sources.jar: org/jboss/metadata/property/PropertiesPropertyResolver.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2013, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.metadata.property;

import java.util.Properties;

/**
 * Resolves properties using a {@code Properties} object.
 *
 * @author John Bailey
 */
public class PropertiesPropertyResolver extends JBossASSimpleExpressionResolver {
    private final Properties deploymentProperties;

    public PropertiesPropertyResolver(final Properties deploymentProperties) {
        this.deploymentProperties = deploymentProperties;
    }

    @Override
    protected String resolveKey(String key) {
        return deploymentProperties.getProperty(key);
    }
}
